OC.L10N.register(
    "core",
    {
    "Please select a file." : "لطفا فایل مورد نظر را انتخاب کنید ",
    "File is too big" : "فایل خیلی بزرگ است",
    "The selected file is not an image." : "فایل انتخاب شده عکس نمی باشد.",
    "The selected file cannot be read." : "فایل انتخاب شده خوانده نمی شود.",
    "Invalid file provided" : "فایل داده‌شده نا معتبر است",
    "No image or file provided" : "هیچ فایل یا تصویری وارد نشده است",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Invalid image" : "عکس نامعتبر",
    "An error occurred. Please contact your admin." : "یک خطا رخ داده است. لطفا با مدیر سیستم تماس بگیرید.",
    "No temporary profile picture available, try again" : "تصویر پروفایل موقت در حال حاضر در دسترس نیست ، دوباره تلاش کنید ",
    "No crop data provided" : "هیچ داده برش داده شده ارائه نشده است",
    "No valid crop data provided" : "هیچ داده برش داده شده معتبر ارائه نشده است",
    "Crop is not square" : "بخش بریده شده مربع نیست",
    "State token does not match" : "State token مطابقت ندارد",
    "Invalid app password" : "کلمه عبور اپلیکیشن اشتباه است",
    "Could not complete login" : "فرایند ورود شما به سیستم کامل نشد",
    "Your login token is invalid or has expired" : "اطلاعات توکن ورود شما اشتباه یا منقضی است",
    "Password reset is disabled" : "تنظیم مجدد رمز عبور فعال نیست",
    "Couldn't reset password because the token is invalid" : "تنظیم مجدد گذرواژه میسر نیست, Token نامعتبر است",
    "Couldn't reset password because the token is expired" : "تنظیم مجدد گذرواژه میسر نیست, Token منقضی شده است",
    "%s password reset" : "%s رمزعبور تغییر کرد",
    "Password reset" : "تنظیم مجدد رمز عبور",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی دکمه زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی لینک زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
    "Reset your password" : "تنظیم مجدد رمز عبور",
    "Some of your link shares have been removed" : "برخی از لینک های اشتراک گذاری شده شما حذف شده است",
    "Preparing update" : "آماده‌سازی به روز‌ رسانی",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Please use the command line updater because automatic updating is disabled in the config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: چک کردن جدول %s",
    "Turned on maintenance mode" : "حالت \" در دست تعمیر \" فعال شد .",
    "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
    "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
    "Updating database schema" : "به روز رسانی طرح پایگاه داده",
    "Updated database" : "بروز رسانی پایگاه داده انجام شد .",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "بررسی اینکه آیا طرح پایگاه داده می تواند به روز شود (این ممکن است بسته به اندازه پایگاه داده طولانی باشد)",
    "Checked database schema update" : "به روز رسانی طرح پایگاه داده بررسی شد",
    "Checking updates of apps" : "بررسی به روزرسانی های برنامه ها",
    "Checking for update of app \"%s\" in appstore" : "بررسی به روزرسانی های برنامه \"%s\" در فروشگاه App",
    "Update app \"%s\" from appstore" : " \"%s\" به روز رسانی شد",
    "Checked for update of app \"%s\" in appstore" : "بررسی به روزرسانی های برنامه %s",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "بررسی اینکه آیا طرح پایگاه داده %s می تواند به روز شود (این ممکن است بسته به اندازه پایگاه داده طولانی باشد)",
    "Checked database schema update for apps" : "Checked database schema update for apps",
    "Set log level to debug" : "Set log level to debug",
    "Reset log level" : "Reset log level",
    "Starting code integrity check" : "Starting code integrity check",
    "Finished code integrity check" : "Finished code integrity check",
    "%s (incompatible)" : "%s (incompatible)",
    "Already up to date" : "در حال حاضر بروز است",
    "Error occurred while checking server setup" : "خطا در هنگام چک کردن راه‌اندازی سرور رخ داده است",
    "unknown text" : "متن نامعلوم",
    "Hello world!" : "سلام دنیا!",
    "sunny" : "آفتابی",
    "Hello {name}, the weather is {weather}" : "سلام {name}, هوا  {weather} است",
    "Hello {name}" : "سلام {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>این نتایج جستجوی شماست <script>alert(1)</script> </strong>",
    "new" : "جدید",
    "_download %n file_::_download %n files_" : ["دانلود %n فایل","دانلود %n فایل"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "به روز رسانی در حال انجام است، این صفحه ممکن است روند در برخی از محیط ها را قطع کند.",
    "Update to {version}" : "بروزرسانی به  {version}",
    "An error occurred." : "یک خطا رخ‌داده است.",
    "Please reload the page." : "لطفا صفحه را دوباره بارگیری کنید.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "به روزرسانی ناموفق بود. برای اطلاعات بیشتر <a href=\"{url}\">فروم ما را بررسی کنید</a>",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
    "Continue to Nextcloud" : "ادامه به Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["به روز رسانی موفقیت آمیز بود هدایت شما به Nextcloud در %nثانیه ","به روز رسانی موفقیت آمیز بود هدایت شما به Nextcloud در %nثانیه "],
    "Log in" : "ورود",
    "Logging in …" : "ورود به سیستم ...",
    "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
    "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
    "An internal error occurred." : "یک اشتباه داخلی رخ داد.",
    "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
    "Username or email" : "نام کاربری یا ایمیل",
    "Password" : "گذرواژه",
    "Wrong username or password." : "شناسه کاربری و کلمه عبور اشتباه است",
    "User disabled" : "کاربر غیرفعال",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
    "Reset password" : "تنظیم مجدد رمز عبور",
    "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
    "Password can not be changed. Please contact your administrator." : "رمز عبور نمی تواند تغییر بکند . لطفا با مدیر سیستم تماس بگیرید .",
    "New password" : "گذرواژه جدید",
    "I know what I'm doing" : "اطلاع از انجام این کار دارم",
    "Resetting password" : "در حال ریست کردن کلمه عبور...",
    "Installing apps …" : "در حال نصب برنامه",
    "Cancel" : "منصرف شدن",
    "Schedule work & meetings, synced with all your devices." : "برنامه کار و جلسات ، همگام سازی با تمام دستگاه های شما",
    "Keep your colleagues and friends in one place without leaking their private info." : "همکاران و دوستان خود را در یک مکان نگه دارید بدون اینکه اطلاعات خصوصی آنها را بشناسید.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها ، مخاطبین و تقویم یکپارچه شده است.",
    "Forgot password?" : "رمز فراموش شده؟",
    "Back" : "بازگشت",
    "Settings" : "تنظیمات",
    "Search contacts …" : "جستجو مخاطبین ...",
    "No contacts found" : "مخاطبین یافت نشد",
    "Show all contacts …" : "نمایش همه مخاطبین ...",
    "Loading your contacts …" : "بارگیری مخاطبین شما ...",
    "Looking for {term} …" : "به دنبال {term} …",
    "No" : "نه",
    "Yes" : "بله",
    "No files in here" : "هیچ فایلی اینجا وجود ندارد",
    "New folder" : "پوشه جدید",
    "Name" : "نام",
    "Size" : "اندازه",
    "Modified" : "تغییر یافته",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" یک نوع پرونده مجاز نیست",
    "{newName} already exists" : "{newName} قبلاً موجود است",
    "Choose" : "انتخاب کردن",
    "Copy" : "کپی",
    "Move" : "انتقال",
    "Error loading file picker template: {error}" : "خطا در بارگذاری قالب انتخاب فایل : {error}",
    "OK" : "تایید",
    "Error loading message template: {error}" : "خطا در بارگذاری قالب پیام : {error}",
    "read-only" : "فقط-خواندنی",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count}  تضاد در فایل","{count}  تضاد در فایل"],
    "One file conflict" : "یک فایل متضاد",
    "New Files" : "فایل های جدید",
    "Already existing files" : "فایل های موجود در حال حاضر ",
    "Which files do you want to keep?" : "کدام فایل ها را می خواهید نگه دارید ؟",
    "If you select both versions, the copied file will have a number added to its name." : "اگر هر دو نسخه را انتخاب کنید، فایل کپی شده یک شماره به نام آن اضافه خواهد شد.",
    "Continue" : "ادامه",
    "(all selected)" : "(همه انتخاب شده اند)",
    "({count} selected)" : "({count} انتخاب شده)",
    "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
    "Pending" : "در انتظار",
    "Copy to {folder}" : "کپی به {folder}",
    "Move to {folder}" : "انتقال به {folder}",
    "Authentication required" : "احراز هویت مورد نیاز است",
    "This action requires you to confirm your password" : "این اقدام نیاز به تایید رمز عبور شما دارد",
    "Confirm" : "تایید",
    "Failed to authenticate, try again" : "تأیید هویت نشد، دوباره امتحان کنید",
    "seconds ago" : "ثانیه‌ها پیش",
    "Connection to server lost" : "اتصال به سرور از دست رفته است",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه","%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه"],
    "Hide details" : "مخفی کردن جزئیات",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "No action available" : "هیچ عملی قابل انجام نیست",
    "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
    "Non-existing tag #{tag}" : "برچسب غیر موجود #{tag}",
    "restricted" : "محدود",
    "invisible" : "غیر قابل مشاهده",
    "Delete" : "حذف",
    "Rename" : "تغییرنام",
    "Collaborative tags" : "برچسب های همکاری",
    "No tags found" : "هیچ برچسبی یافت نشد",
    "Personal" : "شخصی",
    "Users" : "کاربران",
    "Apps" : "  برنامه ها",
    "Admin" : "مدیر",
    "Help" : "راه‌نما",
    "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
    "File not found" : "فایل یافت نشد",
    "Error" : "خطا",
    "Internal Server Error" : "خطای داخلی سرور",
    "The server was unable to complete your request." : "سرور قادر به تکمیل درخواست شما نبود.",
    "If this happens again, please send the technical details below to the server administrator." : "اگر این اتفاق دوباره افتاد، لطفا جزئیات فنی زیر را به مدیر سرور ارسال کنید.",
    "More details can be found in the server log." : "جزئیات بیشتر در لاگ سرور قابل مشاهده خواهد بود.",
    "Technical details" : "جزئیات فنی",
    "Remote Address: %s" : "آدرس راه‌دور: %s",
    "Request ID: %s" : "ID درخواست: %s",
    "Type: %s" : "نوع: %s",
    "Code: %s" : "کد: %s",
    "Message: %s" : "پیام: %s",
    "File: %s" : "فایل : %s",
    "Line: %s" : "خط: %s",
    "Trace" : "ردیابی",
    "Security warning" : "اخطار امنیتی",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
    "Create an <strong>admin account</strong>" : "لطفا یک <strong> شناسه برای مدیر</strong> بسازید",
    "Username" : "نام کاربری",
    "Storage & database" : "انبارش و پایگاه داده",
    "Data folder" : "پوشه اطلاعاتی",
    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
    "Only %s is available." : "تنها %s موجود است.",
    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
    "Database user" : "شناسه پایگاه داده",
    "Database password" : "پسورد پایگاه داده",
    "Database name" : "نام پایگاه داده",
    "Database tablespace" : "جدول پایگاه داده",
    "Database host" : "هاست پایگاه داده",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
    "Performance warning" : "اخطار کارایی",
    "Finish setup" : "اتمام نصب",
    "Finishing …" : "در حال اتمام ...",
    "Need help?" : "کمک لازم دارید ؟",
    "See the documentation" : "مشاهده‌ی مستندات",
    "More apps" : "برنامه های بیشتر",
    "More" : "بیش‌تر",
    "Contacts" : "مخاطبین",
    "Contacts menu" : "منوی دفتر تلفن",
    "Confirm your password" : "گذرواژه خود را تأیید کنید",
    "App token" : "App token",
    "Grant access" : " مجوز اعطا دسترسی",
    "Account access" : "دسترسی به حساب",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
    "Use backup code" : "از کد پشتیبان استفاده شود",
    "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
    "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
    "Start update" : "اغاز به روز رسانی",
    "Detailed logs" : "Detailed logs",
    "Update needed" : "نیاز به روز رسانی دارد",
    "Following apps have been disabled: %s" : "برنامه های زیر غیر فعال شده اند %s",
    "({scope})" : "({scope})",
    "Searching other places" : "جستجو در مکان‌های دیگر",
    "No search results in other folders for {tag}{filter}{endtag}" : "جستجو در پوشه های دیگر برای {tag}{filter}{endtag} یافت نشد",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} نتایج جستجو در پوشه های دیگر","{count} نتایج جستجو در پوشه های دیگر"],
    "Saving..." : "در حال ذخیره سازی...",
    "Search" : "جست‌و‌جو",
    "These apps will be updated:" : "این برنامه‌ها بروزرسانی شده‌اند:"
},
"nplurals=2; plural=(n > 1);");
